==> rc-ui-lib-0.1.58.tgz: package/es/empty/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Button from '../../button';
import { Network } from '../Network';
import Empty from '..';
describe('Empty', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render image correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      image: "search"
    }));
    expect(toJson(wrapper.html())).toMatchSnapshot();
  });
  it('should render description correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      description: "description"
    }));
    expect(toJson(wrapper.html())).toMatchSnapshot();
  });
  it('should render bottom correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, null, /*#__PURE__*/React.createElement(Button, {
      round: true,
      type: "primary",
      className: "bottom-button"
    }, "\u6309\u94AE")));
    expect(toJson(wrapper.html())).toMatchSnapshot();
  });
  it('should render svg when image is network component', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      image: Network
    }));
    expect(toJson(wrapper.html())).toMatchSnapshot();
  });
  it('should render svg when prop image is network', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      image: "network"
    }));
    expect(toJson(wrapper.html())).toMatchSnapshot();
  });
  it('should change image size when using image-size prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var image;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
              image: "search",
              imageSize: 50
            }));
            image = wrapper.find('.rc-empty__image');
            expect(image.getDOMNode().style.width).toEqual('50px');
            expect(image.getDOMNode().style.height).toEqual('50px');
            _context.next = 6;
            return wrapper.setProps({
              imageSize: '1vw'
            });

          case 6:
            expect(image.getDOMNode().style.width).toEqual('1vw');
            expect(image.getDOMNode().style.height).toEqual('1vw');

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/es/empty/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Button from '../../button';
import { Network } from '../Network';
import Empty from '..';
describe('Empty', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render image correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      image: "search"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render description correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      description: "description"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render bottom correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, null, /*#__PURE__*/React.createElement(Button, {
      round: true,
      type: "primary",
      className: "bottom-button"
    }, "\u6309\u94AE")));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render svg when image is network component', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      image: Network
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render svg when prop image is network', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
      image: "network"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should change image size when using image-size prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var image;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Empty, {
              image: "search",
              imageSize: 50
            }));
            image = wrapper.find('.rc-empty__image');
            expect(image.getDOMNode().style.width).toEqual('50px');
            expect(image.getDOMNode().style.height).toEqual('50px');
            _context.next = 6;
            return wrapper.setProps({
              imageSize: '1vw'
            });

          case 6:
            expect(image.getDOMNode().style.width).toEqual('1vw');
            expect(image.getDOMNode().style.height).toEqual('1vw');

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
});
